# Boomack Plug-In Vega

## Installation

If your using the Windows MSI installer for Boomack, this plug-in is installed by default.
You can however, deselect it in the setup dialog during the installation.

The Docker image also contains this plug-in.

If you are using _npm_ for installation, you can install this plug-in with:

==| TABS |==
::| Shell / Command Line
```txt
npm i -g boomack-plugin-vega
```
==|------|==

## Features

PlugIn ID: **`vega`**

### Text Transformation `vega`

Generate HTML with a [Vega](https://vega.github.io/vega/) visualization.

#### Input

The input is expected to be valid JSON or YAML.
It is interpreted as a [Vega specification](https://vega.github.io/vega/docs/) to render.

#### Display Options

- **`vega.padding`**  
    Sets the view padding in pixels.
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_padding) for details.
- **`vega.width`**  
    Sets the view width in pixels.
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_width) for details.
    Note that Vega-Lite overrides this option.
- **`vega.height`**  
    Sets the view height in pixels.
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_height) for details.
    Note that Vega-Lite overrides this option.
- **`vega.renderer`**  
    The renderer to use for the view.
    One of "canvas" (default) or "svg".
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_renderer) for details.
- **`vega.hover`**  
    A boolean or an object.
    Enable [hover event processing](https://vega.github.io/vega/docs/api/view/#view_hover).
    Hover event processing is enabled on Vega by default.  
    Boolean: Enables/disables hover event processing.  
    Object: Optional keys (`hoverSet`, `updateSet`) to specify
    which named encoding sets to invoke upon mouseover and mouseout.

### Text Transformation `vega-lite`

Generate HTML with a [Vega Lite](https://vega.github.io/vega-lite/) visualization.

#### Input

The input is expected to be valid JSON or YAML.
It is interpreted as a [Vega Lite specification](https://vega.github.io/vega-lite/docs/) to render.

#### Display Options

- **`vega.padding`**  
    Sets the view padding in pixels.
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_padding) for details.
- **`vega.zoomFit`**  
    A switch to fit the visualization to the slot size.
    Defaults to `true`.
- **`vega.renderer`**  
    The renderer to use for the view.
    One of "canvas" (default) or "svg".
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_renderer) for details.
- **`vega.hover`**  
    A boolean or an object.
    Enable [hover event processing](https://vega.github.io/vega/docs/api/view/#view_hover).
    Hover event processing is enabled on Vega by default.  
    Boolean: Enables/disables hover event processing.  
    Object: Optional keys (`hoverSet`, `updateSet`) to specify
    which named encoding sets to invoke upon mouseover and mouseout.

### Renderer `vega`

Generate HTML with a [Vega](https://vega.github.io/vega/) visualization.
Takes the Vega specification from display option `vega.spec`
and inserts the resource URL in every `data.[*].url` with is `null`.

#### Input

The input is expected to be a data format, supported by Vega.
In Vega 5 `json`, `csv`, `tsv`, `dsv`, and `topojson` are supported.
The data format must be specified in the Vega specification in `data.[*].format.type`.

#### Display Options

- **`vega.padding`**  
    Sets the view padding in pixels.
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_padding) for details.
- **`vega.width`**  
    Sets the view width in pixels.
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_width) for details.
    Note that Vega-Lite overrides this option.
- **`vega.height`**  
    Sets the view height in pixels.
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_height) for details.
    Note that Vega-Lite overrides this option.
- **`vega.renderer`**  
    The renderer to use for the view.
    One of "canvas" (default) or "svg".
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_renderer) for details.
- **`vega.hover`**  
    A boolean or an object.
    Enable [hover event processing](https://vega.github.io/vega/docs/api/view/#view_hover).
    Hover event processing is enabled on Vega by default.  
    Boolean: Enables/disables hover event processing.  
    Object: Optional keys (`hoverSet`, `updateSet`) to specify
    which named encoding sets to invoke upon mouseover and mouseout.
- **`vega.spec`**  
    An object which is interpreted as a [Vega specification](https://vega.github.io/vega/docs/) to render.
    It should have at least one item in the `data` array with the property `url` set to `null`
    as placeholder for the resource URL.

### Renderer `vega-lite`

Generate HTML with a [Vega Lite](https://vega.github.io/vega-lite/) visualization.
Taking the Vega Lite specification from display option `vega.spec`
and inserting the resource URL in `data.url`.

#### Input

The input is expected to be a data format, supported by Vega Lite.
In Vega Lite 5 `json`, `csv`, `tsv`, and `dsv` are supported.
The data format must be specified in the Vega Lite specification in `data.format.type`.

#### Display Options

- **`vega.padding`**  
    Sets the view padding in pixels.
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_padding) for details.
- **`vega.zoomFit`**  
    A switch to fit the visualization to the slot size.
    Defaults to `true`.
- **`vega.renderer`**  
    The renderer to use for the view.
    One of "canvas" (default) or "svg".
    See [Vega docs](https://vega.github.io/vega/docs/api/view/#view_renderer) for details.
- **`vega.hover`**  
    A boolean or an object.
    Enable [hover event processing](https://vega.github.io/vega/docs/api/view/#view_hover).
    Hover event processing is enabled on Vega by default.  
    Boolean: Enables/disables hover event processing.  
    Object: Optional keys (`hoverSet`, `updateSet`) to specify
    which named encoding sets to invoke upon mouseover and mouseout.
- **`vega.spec`**  
    An object which is interpreted as a [Vega Lite specification](https://vega.github.io/vega-lite/docs/) to render.
    It should have an object in the `data` property with the `url` set to `null`.

### Media Types

The plug-in provides the following media types:

- `application/x-vega-spec`
- `application/x-vega-lite-spec`
